﻿using System;
using System.Drawing;

using CoreFoundation;
using UIKit;
using Foundation;
using Syncfusion.Presentation;
using Syncfusion.PresentationRenderer;
using System.IO;
using System.Xml;

namespace Blank
{
    [Register("UniversalView")]
    public class UniversalView : UIView
    {
        public UniversalView()
        {
            Initialize();
        }

        public UniversalView(RectangleF bounds) : base(bounds)
        {
            Initialize();
        }

        void Initialize()
        {
            BackgroundColor = UIColor.White;
        }
    }

    [Register("UIViewController1")]
    public class UIViewController1 : UIViewController
    {
        public UIViewController1()
        {
        }

        public override void DidReceiveMemoryWarning()
        {
            // Releases the view if it doesn't have a superview.
            base.DidReceiveMemoryWarning();

            // Release any cached data, images, etc that aren't in use.
        }

        public override void ViewDidLoad()
        {
            View = new UniversalView();

            base.ViewDidLoad();

            var btn = UIButton.FromType(UIButtonType.System);
            btn.Frame = new CoreGraphics.CGRect(20, 200, 280, 44);
            btn.SetTitle("Generate PowerPoint Document", UIControlState.Normal);

            var user = new UIViewController();

            btn.TouchUpInside += OnButtonClicked;

            View.AddSubview(btn);
        }

        void OnButtonClicked(object sender, EventArgs args)
        {

            //Assign slide index to 0
            int slideIndex = 0;

            //Assign table index to 0
            int TableIndex = 0;

            //Create an instance of ExcelEngine.
            using (IPresentation pptxDoc = Presentation.Create())
            {
                //Add new blank slide to the presentation
                ISlide slide = pptxDoc.Slides.Add(SlideLayoutType.Blank);

                //Add table to the slide
                ITable table = slide.Shapes.AddTable(9, 3, 0, 60, 300, 450);

                //Iitialize PresentationRenderer
                pptxDoc.PresentationRenderer = new PresentationRenderer();

                //Insert Values to each cell
                InsertCellValues(table);

                for (int i = 0; i < 3; i++)
                {

                    //Get the Actual height of the table 
                    float tableHeight = pptxDoc.Slides[slideIndex].Tables[TableIndex].GetActualHeight() + (float)pptxDoc.Slides[slideIndex].Tables[TableIndex].Top;

                    //Compare table height with the slide height
                    if (tableHeight > (float)slide.SlideSize.Height)
                    {

                        //Add table to the slide
                        ITable newTable = pptxDoc.Slides.Add(SlideLayoutType.Blank).Shapes.AddTable(5, 3, 0, 50, 300, 350);

                        //Insert Values to each cell
                        InsertCellValues(newTable);

                        //Increase the slide index to iterate the new slide
                        slideIndex++;
                    }
                    else
                    {
                        //Add new Row to the table
                        IRow row = table.Rows.Add();

                        //Insert Value to the table
                        InsertRowValues(row);


                    }
                }

                //Save the workbook to stream in xlsx format. 
                MemoryStream stream = new MemoryStream();
                pptxDoc.Save(stream);

                pptxDoc.Close();

                //Save the stream as a file in the device and invoke it for viewing
                SaveIOS saveIOS = new SaveIOS();
                saveIOS.SaveAndView("GettingStared.pptx", "application/vnd.openxmlformats-officedocument.presentationml.presentation", stream);
            }
        }
         void InsertCellValues(ITable table)
        {
            foreach (IRow row in table.Rows)
            {
                foreach (ICell cell in row.Cells)
                {
                    cell.TextBody.Text = "Syncfusion";
                }
            }
        }

       void InsertRowValues(IRow row)
        {
            foreach (ICell cell in row.Cells)
            {
                cell.TextBody.Text = "Syncfusion";
            }
        }
    }
}